<?php

/*
Plugin Name: reCaptcha for bbPress 2.0
Plugin URI: http://pippinsplugins.com/bbpress-recaptcha
Description: Adds reCaptcha to the bbPress 2.0 topic reply form 
Version: 1.0.3
Author: Pippin Williamson
Contributors: mordauk
Author URI: http://pippinsplugins.com
*/

require_once('recaptchalib.php');

$bbpc_options = get_option('bbpc_settings');

// adds the reCaptcha to the reply to topic form
function bbpc_display_reply_recaptcha() {
	
	global $bbpc_options;
	if(!current_user_can('manage_options')) {
		if(is_user_logged_in() && !isset($bbpc_options['show_to_logged_in']))
			return;
		
		$publickey = $bbpc_options['public_key']; // you got this from the signup page
		echo recaptcha_get_html($publickey);
	}
}
add_action('bbp_theme_before_reply_form_submit_wrapper', 'bbpc_display_reply_recaptcha');

// adds the reCaptcha to the new topic creation form
function bbpc_display_topic_recaptcha() {
	
	global $bbpc_options;
	if(!current_user_can('manage_options')) {	
		if(is_user_logged_in() && !isset($bbpc_options['show_to_logged_in']))
			return;
			
		$publickey = $bbpc_options['public_key']; // you got this from the signup page
		echo recaptcha_get_html($publickey);
	}
}
add_action('bbp_theme_before_topic_form_submit_wrapper', 'bbpc_display_topic_recaptcha');

function bbpc_validate_reply_recaptcha($reply_id) {
	if(!current_user_can('manage_options')) {	
		global $bbpc_options;

		if(is_user_logged_in() && !isset($bbpc_options['show_to_logged_in']))
			return;
		
		$privatekey = $bbpc_options['private_key'];
		$resp = recaptcha_check_answer(
			$privatekey,
			$_SERVER["REMOTE_ADDR"],
			$_POST["recaptcha_challenge_field"],
			$_POST["recaptcha_response_field"]
		);
		
		if (!$resp->is_valid) {
			bbp_add_error( 'bbp_reply_duplicate', __( '<strong>ERROR</strong>: The words you entered were incorrect', 'bbpress' ) );
		}
	}
}
add_action('bbp_new_reply_pre_extras', 'bbpc_validate_reply_recaptcha');

function bbpc_validate_topic_recaptcha($reply_id) {
	if(!current_user_can('manage_options')) {	
		global $bbpc_options;

		if(is_user_logged_in() && !isset($bbpc_options['show_to_logged_in']))
			return;
		
		$privatekey = $bbpc_options['private_key'];
		$resp = recaptcha_check_answer(
			$privatekey,
			$_SERVER["REMOTE_ADDR"],
			$_POST["recaptcha_challenge_field"],
			$_POST["recaptcha_response_field"]
		);
		
		if (!$resp->is_valid) {
			bbp_add_error( 'bbp_reply_duplicate', __( '<strong>ERROR</strong>: The words you entered were incorrect', 'bbpress' ) );
		}
	}
}
add_action('bbp_new_topic_pre_extras', 'bbpc_validate_topic_recaptcha');


/*******************************************
* ettings Page
*******************************************/

function bbpc_settings_page()
{
	global $bbpc_options;
		
	?>
	<div class="wrap">
		<h2>bbPress reCaptcha Settings</h2>
		<?php
		if ( ! isset( $_REQUEST['updated'] ) )
			$_REQUEST['updated'] = false;
		?>
		<?php if ( false !== $_REQUEST['updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved' ); ?></strong></p></div>
		<?php endif; ?>
		<form method="post" action="options.php">

			<?php settings_fields( 'bbpc_settings_group' ); ?>
			
			<h4>reCaptcha Keys</h4>
			<p>
				<label for="bbpc_settings[public_key]"><?php _e( 'reCaptcha Public Key' ); ?></label><br/>
				<input id="bbpc_settings[public_key]" style="width: 300px;" name="bbpc_settings[public_key]" type="text" value="<?php echo $bbpc_options['public_key'];?>" />
				<p class="description">This your own personal reCaptcha Public key. Go to <a href="https://www.google.com/recaptcha/admin/list">your account</a>, then click on your domain (or add a new one) to find your public key.</p>
			</p>
			<p>
				<label for="bbpc_settings[private_key]"><?php _e( 'reCaptcha Private Key' ); ?></label><br/>
				<input id="bbpc_settings[private_key]" style="width: 300px;" name="bbpc_settings[private_key]" type="text" value="<?php echo $bbpc_options['private_key'];?>" />
				<p class="description">This your own personal reCaptcha Private key. Go to <a href="https://www.google.com/recaptcha/admin/list">your account</a>, then click on your domain (or add a new one) to find your private key.</p>
			</p>
			<p>
				<input id="bbpc_settings[show_to_logged_in]" name="bbpc_settings[show_to_logged_in]" type="checkbox" value="1" <?php checked('1', $bbpc_options['show_to_logged_in']); ?>/>
				<label for="bbpc_settings[show_to_logged_in]"><?php _e( 'Show to logged-in users?' ); ?></label><br/>
				<p class="description">Require the logged in users fill out the reCaptcha form? Note, admins are always excluded.</p>
			</p>
			
			<!-- save the options -->
			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options' ); ?>" />
			</p>
							
			
		</form>
	</div><!--end wrap-->
		
	<?php
}

// register the plugin settings
function bbpc_register_settings() {

	// create whitelist of options
	register_setting( 'bbpc_settings_group', 'bbpc_settings' );
}
//call register settings function
add_action( 'admin_init', 'bbpc_register_settings' );


function bbpc_settings_menu() {

	// add settings page
	add_submenu_page('options-general.php', 'bbPress reCaptcha Settings', 'bbPress reCaptcha','manage_options', 'bbpress-recaptcha-settings', 'bbpc_settings_page');
}
add_action('admin_menu', 'bbpc_settings_menu');
